summaryrefslogtreecommitdiff
path: root/src/wasm-linker.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/wasm-linker.cpp')
-rw-r--r--src/wasm-linker.cpp14
1 files changed, 5 insertions, 9 deletions
diff --git a/src/wasm-linker.cpp b/src/wasm-linker.cpp
index a319af889..757fc88ca 100644
--- a/src/wasm-linker.cpp
+++ b/src/wasm-linker.cpp
@@ -254,20 +254,16 @@ void Linker::layout() {
}
}
// Export malloc, realloc, and free whenever availble. JavsScript version of
// malloc has some issues and it cannot be called once _sbrk() is called, and
// JS glue code does not have realloc(). TODO This should get the list of
// exported functions from emcc.py - it has EXPORTED_FUNCTION metadata to keep
// track of this. Get the list of exported functions using a command-line
// argument from emcc.py and export all of them.
- if (out.symbolInfo.implementedFunctions.count("malloc")) {
- exportFunction("malloc", true);
- }
- if (out.symbolInfo.implementedFunctions.count("free")) {
- exportFunction("free", true);
- }
- if (out.symbolInfo.implementedFunctions.count("realloc")) {
- exportFunction("realloc", true);
+ for (auto function : {"malloc", "free", "realloc", "memalign"}) {
+ if (out.symbolInfo.implementedFunctions.count(function)) {
+ exportFunction(function, true);
+ }
}
// finalize function table
@@ -254,20 +254,16 @@ void Linker::layout() {
}
}
- // Export malloc, realloc, and free whenever availble. JavsScript version of
+ // Export malloc/realloc/free/memalign whenever availble. JavsScript version of
// malloc has some issues and it cannot be called once _sbrk() is called, and
// JS glue code does not have realloc(). TODO This should get the list of